@@ -200,59 +200,3 @@ class _S3Dict: # class _S3Dict(dict): # TODO: implement dict (or OrderedDict) in
                                'Status': 'Enabled'}]})
         else:
             raise TypeError('Expected days argument to be an non-zero positive integer or None')
-
-
-if __name__ == '__main__':
-    # AWS_PROFILE=myprofile python s3_memoize.py 
-
-    # # from functools import lru_cache
-    # # @lru_cache(maxsize=128, typed=False)
-    # @s3_fifo_cache(maxsize=2, typed=False, bucket_name='rl-colloquium-test')
-    # # @s3_lru_cache(maxsize=2, typed=False, bucket_name='rl-colloquium-test')
-    # def test(num):
-    #     print(f'test: {num}')
-    #     return num * 2
-
-    # print(test.cache_clear())
-    # print(test.cache_info())
-    # print(test(10))
-    # print(test.cache_info())
-    # print(test(10))
-    # print(test.cache_info())
-    # print(test(20))
-    # print(test.cache_info())
-    # print(test(20))
-    # print(test.cache_info())
-    # print(test(10))
-    # print(test.cache_info())
-    # print(test(30))
-    # print(test.cache_info())
-    # print(test(30))
-    # print(test.cache_info())
-
-    # @s3_fifo_cache(maxsize=2, typed=False, bucket_name='rl-colloquium-test')
-    # @s3_lru_cache(maxsize=0, typed=False, bucket_name='rl-colloquium-test')
-    def test(s):
-        print(f'test: {s}')
-        return 'hello ' + str(s)
-    # test = s3_lru_cache(test, typed=False, bucket_name='rl-colloquium-test')
-
-    print(test.cache_clear())
-    print(test.cache_info())
-    print(test('abc'))
-    print(test.cache_info())
-    print(test('abc'))
-    print(test.cache_info())
-    print(test('ABC'))
-    print(test.cache_info())
-    print(test('ABC'))
-    print(test.cache_info())
-    print(test('abc'))
-    print(test.cache_info())
-    print(test('def'))
-    print(test.cache_info())
-    print(test('def'))
-    print(test.cache_info())
-
-    # cache = _S3Dict('rl-colloquium-test', is_lru=False)
-    # cache.set_expiration(days=1)
